//+------------------------------------------------------------------+
//|                                                     My Panel.mq4 |
//|                        Copyright 2021, MetaQuotes Software Corp. |
//|                                             https://www.mql5.com |
//+------------------------------------------------------------------+
#property copyright "Copyright 2021, MetaQuotes Software Corp."
#property link      "https://www.mql5.com"
#property version   "1.00"
#property strict

#include <Controls\Dialog.mqh>
#include <Controls\Label.mqh>
#include <Controls\Edit.mqh>
//+------------------------------------------------------------------+
//| defines                                                          |
//+------------------------------------------------------------------+
//--- indents and gaps
#define INDENT_LEFT                         (11)      // indent from left (with allowance for border width)
#define INDENT_TOP                          (11)      // indent from top (with allowance for border width)
#define CONTROLS_GAP_X                      (5)       // gap by X coordinate
//--- for buttons
#define BUTTON_WIDTH                        (80)     // size by X coordinate
#define BUTTON_HEIGHT                       (20)      // size by Y coordinate
//---
//+------------------------------------------------------------------+
//| Class CAppWindowMyPanel                                       |
//| Usage: main dialog of the Controls application                   |
//+------------------------------------------------------------------+
class CAppWindowMyPanel : public CAppDialog
  {
private:
   CLabel            Spread_Label;                       // the label object
   CLabel            CandleSize_Label;                    // the label object
   
   CEdit             Spread_Edit;                        // the edit object
   CEdit             CandleSize_Edit;                     // the edit object 
   
public:
                     CAppWindowMyPanel(void);
                    ~CAppWindowMyPanel(void);
   //--- create
   virtual bool      Create(const long chart,const string name,const int subwin,const int x1,const int y1,const int x2,const int y2);
     //--- chart event handler
   virtual bool      OnEvent(const int id,const long &lparam,const double &dparam,const string &sparam);

protected:
   //--- create dependent controls
   bool              CreateSpread_Label(void);
   bool              CreateCandleSize_Label(void);
   
   bool              CreateSpread_Edit(void);
   bool              CreateCandleSize_Edit(void);  
  };
//+------------------------------------------------------------------+
//| Event Handling                                                   |
//+------------------------------------------------------------------+
EVENT_MAP_BEGIN(CAppWindowMyPanel)
EVENT_MAP_END(CAppDialog)
//+------------------------------------------------------------------+
//| Constructor                                                      |
//+------------------------------------------------------------------+
CAppWindowMyPanel::CAppWindowMyPanel(void)
  {
  }
//+------------------------------------------------------------------+
//| Destructor                                                       |
//+------------------------------------------------------------------+
CAppWindowMyPanel::~CAppWindowMyPanel(void)
  {
  }
//+------------------------------------------------------------------+
//| Create                                                           |
//+------------------------------------------------------------------+
bool CAppWindowMyPanel::Create(const long chart,const string name,const int subwin,const int x1,const int y1,const int x2,const int y2)
  {
   if(!CAppDialog::Create(chart,name,subwin,x1,y1,x2,y2))
      return(false);
//--- create dependent controls
   if(!CreateSpread_Label())
      return(false);
   if(!CreateCandleSize_Label())
      return(false);                      
   if(!CreateSpread_Edit())
      return(false); 
   if(!CreateCandleSize_Edit())
      return(false);                       
//--- succeed
   return(true);
  }
//+------------------------------------------------------------------+
//| Global Variable                                                  |
//+------------------------------------------------------------------+
CAppWindowMyPanel ExtDialog;
//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit()
  {  
//--- create application dialog
   if(!ExtDialog.Create(0,"My Panel",0,40,40,240,140))
      return(INIT_FAILED);
//--- run application
   ExtDialog.Run();
//--- succeed
   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
   Comment("");
//--- destroy dialog
   ExtDialog.Destroy(reason);   
  }  
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
  {     
   int myPoint = 1;
   if(Digits == 3 || Digits == 5) myPoint = 10;   
   double Spread = NormalizeDouble((MarketInfo(Symbol(), MODE_SPREAD)),MarketInfo(Symbol(),MODE_DIGITS))/myPoint;
   
   //Transfer Spread in Spread_Edit
  }  
//+------------------------------------------------------------------+
//| Expert chart event function                                      |
//+------------------------------------------------------------------+
void OnChartEvent(const int id,         // event ID  
                  const long& lparam,   // event parameter of the long type
                  const double& dparam, // event parameter of the double type
                  const string& sparam) // event parameter of the string type
  {
   ExtDialog.ChartEvent(id,lparam,dparam,sparam);
   
   if(id==CHARTEVENT_CLICK)
     {
      datetime time = 0;
      double price = 0;
      int window = 0;
      if (ChartXYToTimePrice(ChartID(),int(lparam),int(dparam),window,time,price))
      {
       int bar = iBarShift(Symbol(),Period(),time);
       double ticksize = MarketInfo(Symbol(), MODE_TICKSIZE);        
       double CandleSize = NormalizeDouble((iHigh(Symbol(),Period(),bar) - iLow(Symbol(),Period(),bar)),Digits);
       
       //Transfer CandleSize in CandleSize_Edit               
      }
     }         
   }
//+------------------------------------------------------------------+
//| Create the Spread Label                                          |
//+------------------------------------------------------------------+
bool CAppWindowMyPanel::CreateSpread_Label(void)
  {
//--- coordinates
   int x1=INDENT_LEFT+0*(BUTTON_WIDTH+CONTROLS_GAP_X);        
   int y1=INDENT_TOP+0*(BUTTON_HEIGHT+CONTROLS_GAP_X);       
   int x2=x1+BUTTON_WIDTH;                                    
   int y2=y1+BUTTON_HEIGHT;                                   
//--- create
   if(!Spread_Label.Create(0,"Spread_Label",0,x1,y1,x2,y2))
      return(false);
   if(!Spread_Label.Text("Spread:"))
      return(false);
   if(!Add(Spread_Label))
      return(false);
//--- succeed
   return(true);
  }
//+------------------------------------------------------------------+
//| Create the Candle Size Label                                     |
//+------------------------------------------------------------------+
bool CAppWindowMyPanel::CreateCandleSize_Label(void)
  {
//--- coordinates
   int x1=INDENT_LEFT+0*(BUTTON_WIDTH+CONTROLS_GAP_X);       
   int y1=INDENT_TOP+1*(BUTTON_HEIGHT+CONTROLS_GAP_X);       
   int x2=x1+BUTTON_WIDTH;                                    
   int y2=y1+BUTTON_HEIGHT;                                   
//--- create
   if(!CandleSize_Label.Create(0,"CandleSize_Label",0,x1,y1,x2,y2))
      return(false);
   if(!CandleSize_Label.Text("Candle Size:"))
      return(false);
   if(!Add(CandleSize_Label))
      return(false);
//--- succeed
   return(true);
  }
//+------------------------------------------------------------------+
//| Create the Spread Edit                                           |
//+------------------------------------------------------------------+  
bool CAppWindowMyPanel::CreateSpread_Edit(void)
  {
int x1=INDENT_LEFT+1*(BUTTON_WIDTH+CONTROLS_GAP_X);   
   int y1=INDENT_TOP;                                   
   int x2=x1+BUTTON_WIDTH;                             
   int y2=y1+BUTTON_HEIGHT;                            
//--- create
   if(!Spread_Edit.Create(0,"Spread_Edit",0,x1,y1,x2,y2))
      return(false);       
   if(!Add(Spread_Edit))
      return(false);
//--- succeed
   return(true);
  }
//+------------------------------------------------------------------+
//| Create the Candle Size Edit                                      |
//+------------------------------------------------------------------+   
bool CAppWindowMyPanel::CreateCandleSize_Edit(void)
  {
int x1=INDENT_LEFT+1*(BUTTON_WIDTH+CONTROLS_GAP_X);   
   int y1=INDENT_TOP+1*(BUTTON_HEIGHT+CONTROLS_GAP_X);  
   int x2=x1+BUTTON_WIDTH;                              
   int y2=y1+BUTTON_HEIGHT;     
//--- create
   if(!CandleSize_Edit.Create(0,"CandleSize_Edit",0,x1,y1,x2,y2))
      return(false);   
   if(!Add(CandleSize_Edit))
      return(false);
//--- succeed
   return(true);  
   }